@@ -15,7 +15,7 @@ from ..data_processor._random_string_data import RandomStringData
 from ..data_processor._random_time_data import RandomTimeData
 from ..data_processor._sql_cache import SqlCache
 from ..exceptions import MangoToolsError
-from ..exceptions.error_msg import ERROR_MSG_0047, ERROR_MSG_0002, ERROR_MSG_0022
+from ..exceptions.error_msg import ERROR_MSG_0047, ERROR_MSG_0002, ERROR_MSG_0022, ERROR_MSG_0023
 from ..mangos import Mango
 
 """
@@ -28,7 +28,7 @@ class ObtainRandomData(RandomNumberData, RandomCharacterInfoData, RandomTimeData
 
     def regular(self, func: str):
         try:
-            return Mango.regular(self, func, MangoToolsError, ERROR_MSG_0022)
+            return Mango.regular(self, func, MangoToolsError, ERROR_MSG_0022, ERROR_MSG_0023)
         except AttributeError as e:
             raise MangoToolsError(*ERROR_MSG_0047, value=(func, e))
 
