@@ -21,6 +21,17 @@ class RandomStringData:
         """随机的UUID，长度36"""
         return str(uuid.uuid4())
 
+    @classmethod
+    def str_random_string(cls, length=10):
+        """随机字母数字,参数：length（默认10）"""
+        try:
+            length = int(length)
+        except ValueError:
+            raise MangoToolsError(*ERROR_MSG_0006)
+        characters = string.ascii_letters + string.digits
+        random_string = ''.join(random.choice(characters) for _ in range(length))
+        return random_string
+
     @classmethod
     def str_city(cls):
         """获取城市"""
@@ -51,17 +62,6 @@ class RandomStringData:
         """生成一篇文章"""
         return cls.faker.text()
 
-    @classmethod
-    def str_random_string(cls, length=10):
-        """随机字母数字,参数：length（默认10）"""
-        try:
-            length = int(length)
-        except ValueError:
-            raise MangoToolsError(*ERROR_MSG_0006)
-        characters = string.ascii_letters + string.digits
-        random_string = ''.join(random.choice(characters) for _ in range(length))
-        return random_string
-
     @classmethod
     def str_lowercase(cls, length=10):
         """生成指定长度的纯小写字母字符串,参数：length（默认10）"""
@@ -78,15 +78,6 @@ class RandomStringData:
         special_chars = '!@#$%^&*()-_=+[]{}|;:,.<>?/'
         return ''.join(random.choices(special_chars, k=int(length)))
 
-    @classmethod
-    def str_email(cls):
-        """生成随机邮箱"""
-        return cls.faker.email()
-
-    @classmethod
-    def str_phone_number(cls):
-        """生成随机手机号"""
-        return cls.faker.phone_number()
 
     @classmethod
     def str_url(cls):
@@ -123,30 +114,7 @@ class RandomStringData:
         """生成随机日期时间字符串（YYYY-MM-DD HH:MM:SS）"""
         return cls.faker.date_time().strftime('%Y-%m-%d %H:%M:%S')
 
-    @classmethod
-    def str_company(cls):
-        """生成随机公司名"""
-        return cls.faker.company()
 
-    @classmethod
-    def str_name(cls):
-        """生成随机人名"""
-        return cls.faker.name()
-
-    @classmethod
-    def str_credit_card(cls):
-        """生成随机银行卡号"""
-        return cls.faker.credit_card_number()
-
-    @classmethod
-    def str_ssn(cls):
-        """生成随机身份证号（中国大陆18位）"""
-        return cls.faker.ssn()
-
-    @classmethod
-    def str_license_plate(cls):
-        """生成随机车牌号"""
-        return cls.faker.license_plate()
 
     @classmethod
     def str_url_path(cls):
@@ -173,25 +141,13 @@ class RandomStringData:
         """生成随机英文段落"""
         return cls.faker.paragraph()
 
-    @classmethod
-    def str_cn_name(cls):
-        """生成随机中文姓名"""
-        return cls.faker.name()
 
     @classmethod
     def str_cn_address(cls):
         """生成随机中文地址"""
         return cls.faker.address()
 
-    @classmethod
-    def str_postcode(cls):
-        """生成随机邮政编码"""
-        return cls.faker.postcode()
 
-    @classmethod
-    def str_company_email(cls):
-        """生成随机公司邮箱"""
-        return cls.faker.company_email()
 
     @classmethod
     def str_domain(cls):
@@ -221,12 +177,6 @@ class RandomStringData:
         """生成随机经纬度字符串"""
         return f"{cls.faker.latitude()},{cls.faker.longitude()}"
 
-    @classmethod
-    def str_html_tag(cls):
-        """生成随机HTML标签字符串"""
-        tag = random.choice(['div', 'span', 'a', 'p', 'img', 'ul', 'li', 'table', 'tr', 'td'])
-        return f"<{tag}>{cls.faker.word()}</{tag}>"
-
     @classmethod
     def str_json(cls):
         """生成随机JSON字符串"""
@@ -252,27 +202,8 @@ class RandomStringData:
         """生成随机颜色名"""
         return cls.faker.color_name()
 
-    @classmethod
-    def str_job(cls):
-        """生成随机职业"""
-        return cls.faker.job()
 
-    @classmethod
-    def str_university(cls):
-        """生成随机大学名"""
-        return cls.faker.university()
 
-    @classmethod
-    def str_company_job(cls):
-        """生成随机公司职位"""
-        return cls.faker.job()
-
-    @classmethod
-    def str_html_fragment(cls):
-        """生成随机HTML片段字符串"""
-        tag = random.choice(['div', 'span', 'a', 'p', 'img'])
-        attr = f'id="{cls.faker.word()}" class="{cls.faker.word()}"'
-        return f'<{tag} {attr}>{cls.faker.sentence()}</{tag}>'
 
     @classmethod
     def str_markdown(cls):
@@ -287,22 +218,12 @@ class RandomStringData:
         val = cls.faker.word()
         return f"SELECT * FROM {table} WHERE {col}='{val}';"
 
-    @classmethod
-    def str_xml_fragment(cls):
-        """生成随机XML片段字符串"""
-        tag = cls.faker.word()
-        return f'<{tag}>{cls.faker.word()}</{tag}>'
-
     @classmethod
     def str_url_params(cls, count=3):
         """生成随机URL参数字符串,参数：count（默认3）"""
         params = [f'{cls.faker.word()}={cls.faker.word()}' for _ in range(int(count))]
         return '&'.join(params)
 
-    @classmethod
-    def str_intl_phone(cls):
-        """生成随机国际电话号码字符串"""
-        return cls.faker.phone_number().replace('-', ' ')
 
     @classmethod
     def str_card_number_split(cls):
