@@ -5,6 +5,7 @@
 # @Author : 毛鹏
 import asyncio
 import functools
+import traceback
 
 import time
 
@@ -19,6 +20,7 @@ def async_retry(failed_retry_time=25, retry_waiting_time=0.1):
                     return await func(*args, **kwargs)
                 except Exception as error:
                     if (time.time() - start_time) > failed_retry_time:
+                        traceback.print_exc()
                         raise error
                 await asyncio.sleep(retry_waiting_time)
 
@@ -37,6 +39,7 @@ def sync_retry(failed_retry_time=25, retry_waiting_time=0.1):
                     return func(*args, **kwargs)
                 except Exception as error:
                     if (time.time() - start_time) > failed_retry_time:
+                        traceback.print_exc()
                         raise error
                 time.sleep(retry_waiting_time)
 
