@@ -50,28 +50,22 @@ class WeChatSend:
             ])
 
             # 接口相关统计
-            if self.test_report.api_case_sum is not None:
+            if self.test_report.api_case_sum is not None and self.test_report.api_case_sum > 0:
                 lines.append(f">接口用例数：{self.test_report.api_case_sum}")
-            if self.test_report.api_fail is not None:
-                lines.append(f">接口失败数：{self.test_report.api_fail}")
-            if self.test_report.api_call is not None:
-                lines.append(f">接口调用数：{self.test_report.api_call}")
+                if self.test_report.api_fail is not None:
+                    lines.append(f">接口失败数：{self.test_report.api_fail}")
 
             # 前端相关统计
-            if self.test_report.ui_case_sum is not None:
+            if self.test_report.ui_case_sum is not None and self.test_report.ui_case_sum > 0:
                 lines.append(f">前端用例数：{self.test_report.ui_case_sum}")
-            if self.test_report.ui_fail is not None:
-                lines.append(f">前端失败数：{self.test_report.ui_fail}")
-            if self.test_report.ui_step_call is not None:
-                lines.append(f">前端步骤数：{self.test_report.ui_step_call}")
+                if self.test_report.ui_fail is not None:
+                    lines.append(f">前端失败数：{self.test_report.ui_fail}")
 
             # 单元测试相关统计
-            if self.test_report.pytest_case_sum is not None:
+            if self.test_report.pytest_case_sum is not None and self.test_report.pytest_case_sum > 0:
                 lines.append(f">单元用例数：{self.test_report.pytest_case_sum}")
-            if self.test_report.pytest_fail is not None:
-                lines.append(f">单元用例失败数：{self.test_report.pytest_fail}")
-            if self.test_report.pytest_func_call is not None:
-                lines.append(f">单元函数数：{self.test_report.pytest_func_call}")
+                if self.test_report.pytest_fail is not None:
+                    lines.append(f">单元用例失败数：{self.test_report.pytest_fail}")
 
             # 执行信息
             lines.extend([
