@@ -8,7 +8,7 @@ import unittest
 
 from mangotools.assertion import MangoAssertion, FileAssertion
 
-FILE_PATH = r'D:\GitCode\mango_tools\tests\任务爬取逻辑.xlsx'
+FILE_PATH = r'D:\code\mango_tools\tests\任务爬取逻辑.xlsx'
 SHEET_NAME = 'Sheet1'
 
 
@@ -86,7 +86,7 @@ class TestExcelTaskSheet(unittest.TestCase):
         MangoAssertion().ass(FileAssertion.assert_excel_column_values.__name__, actual, expect)
 
     def test_excel_column_values1(self):
-        actual = {'文件路径': r"D:\GitCode\mango_tools\tests\任务爬取逻辑.xlsx",
+        actual = {'文件路径': r"D:\code\mango_tools\tests\任务爬取逻辑.xlsx",
                   '工作表': SHEET_NAME}
         expect = {'单元格': 'A2', '预期值': '301'}
         print(MangoAssertion().ass(FileAssertion.assert_excel_is_equal_to.__name__, actual, expect))
