@@ -66,7 +66,7 @@ class TestSqlCache(unittest.TestCase):
         test_json = {"name": "John", "age": 30, "city": "New York"}
         self.cache.set_sql_cache("test_json", test_json, CacheValueTypeEnum.JSON)
         print(type(self.cache.get_sql_cache("test_json")), self.cache.get_sql_cache("test_json"))
-        assert self.cache.get_sql_cache("test_json") == test_json
+        assert self.cache.get_sql_cache("test_json") == json.dumps(test_json)
 
     def test_10(self):
         print(json.dumps(self.cache.get_sql_all()))
